@@ -30,7 +30,9 @@ def main():
     DjangoInstrumentor().instrument()
 
     try:
-        from django.core.management import execute_from_command_line
+        from django.core.management import (  # noqa: PLC0415
+            execute_from_command_line,
+        )
     except ImportError as exc:
         raise ImportError(
             "Couldn't import Django. Are you sure it's installed and "
