@@ -57,21 +57,13 @@ from opentelemetry.sdk.trace.export import (
     SpanExporter,
     SpanExportResult,
 )
+from opentelemetry.test.mock_test_classes import IterEntryPoint
 
 logger = getLogger(__name__)
 
 
-class IterEntryPoint:
-    def __init__(self, name, class_type):
-        self.name = name
-        self.class_type = class_type
-
-    def load(self):
-        return self.class_type
-
-
 # The below tests use this test SpanExporter and Spans, but are testing the
-# underlying behavior in the mixin. A MetricExporter or LogExporter could
+# underlying behavior in the mixin. A MetricExporter or LogRecordExporter could
 # just as easily be used.
 class OTLPSpanExporterForTesting(
     SpanExporter,
