@@ -15,21 +15,29 @@
 from opentelemetry.sdk._logs._internal.export import (
     BatchLogRecordProcessor,
     ConsoleLogExporter,
+    ConsoleLogRecordExporter,
     LogExporter,
     LogExportResult,
+    LogRecordExporter,
+    LogRecordExportResult,
     SimpleLogRecordProcessor,
 )
 
 # The point module is not in the export directory to avoid a circular import.
 from opentelemetry.sdk._logs._internal.export.in_memory_log_exporter import (
     InMemoryLogExporter,
+    InMemoryLogRecordExporter,
 )
 
 __all__ = [
     "BatchLogRecordProcessor",
     "ConsoleLogExporter",
+    "ConsoleLogRecordExporter",
     "LogExporter",
+    "LogRecordExporter",
     "LogExportResult",
+    "LogRecordExportResult",
     "SimpleLogRecordProcessor",
     "InMemoryLogExporter",
+    "InMemoryLogRecordExporter",
 ]
