@@ -22,5 +22,5 @@ The list of IPv4 or IPv6 addresses resolved during DNS lookup.
 DNS_QUESTION_NAME: Final = "dns.question.name"
 """
 The name being queried.
-Note: If the name field contains non-printable characters (below 32 or above 126), those characters should be represented as escaped base 10 integers (\\DDD). Back slashes and quotes should be escaped. Tabs, carriage returns, and line feeds should be converted to \\t, \\r, and \\n respectively.
+Note: The name represents the queried domain name as it appears in the DNS query without any additional normalization.
 """
